@@ -34,16 +34,16 @@ class DetectorHttpConnector:
         self._connector = HttpServerConnector(config, context)
         self.detector_settings_type = detector_settings_type
 
-    async def get_settings(self, stream_url: str, token: str) -> T:
+    async def get_settings(self, stream_urls: list[str], token: str) -> list[T]:
         payload = {
                 "token": token,
-                "stream_url": stream_url
+                "stream_url": stream_urls
         }
         answer = await self._connector.get("/settings/get",
                                            url_query=payload,
                                            headers=self._construct_headers())
 
-        return dict_to_dataclass(answer["result"], self.detector_settings_type)
+        return [dict_to_dataclass(settings, self.detector_settings_type) for settings in answer["result"]]
 
     async def set_settings(self, detector_settings: T, token: str) -> T:
         payload = {"token": token}
